#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
#
# 2022-11-30: fixed CheckParameterRulespecWithoutItem (from CheckParameterRulespecWithItem)'

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Tuple,
    Integer,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_threat_emulation():
    return Dictionary(
        elements=[
            ('used_monthly_quota_levels',
             Tuple(
                 title=_('Levels for used monthly quota on cloud'),
                 elements=[
                     Integer(title=_('Warning at'), default_value=90, unit=_('%')),
                     Integer(title=_('Critical at'), default_value=95, unit=_('%')),
                 ])),
            ('remaining_quota_levels',
             Tuple(
                 title=_('Levels for remaining quota on cloud'),
                 elements=[
                     Integer(title=_('Warning at'), default_value=10000, unit=_('Files')),
                     Integer(title=_('Critical at'), default_value=5000, unit=_('Files')),
                 ])),
            ('files_waiting_levels',
             Tuple(
                 title=_('Levels for files waiting for emulation'),
                 elements=[
                     Integer(title=_('Warning at'), default_value=5, unit=_('Files')),
                     Integer(title=_('Critical at'), default_value=10, unit=_('Files')),
                 ])),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_threat_emulation',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_threat_emulation,
        title=lambda: _('Check Point Threat Emulation status'),
    ))
